@@ -69,4 +69,4 @@ class TestGnomeScreensaver(dbusmock.DBusTestCase):
 
 if __name__ == '__main__':
     # avoid writing to stderr
-    unittest.main(testRunner=unittest.TextTestRunner(stream=sys.stdout, verbosity=2))
+    unittest.main(testRunner=unittest.TextTestRunner(stream=sys.stdout))
